@@ -1,5 +1,5 @@
 ##
-# Copyright 2009-2019 Ghent University
+# Copyright 2009-2020 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -32,3 +32,5 @@ which is a collection of additional modules/classes to be used for software comp
 :author: Pieter De Baets (Ghent University)
 :author: Jens Timmerman (Ghent University)
 """
+import os
+__path__ = __import__('pkgutil').extend_path([os.path.abspath(p) for p in __path__], __name__)
