@@ -39,6 +39,7 @@ from easybuild.base import fancylogger
 from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.py2vs3 import string_type
 from easybuild.tools.systemtools import get_shared_lib_ext, pick_dep_version
+from easybuild.tools.config import build_option
 
 
 _log = fancylogger.getLogger('easyconfig.templates', fname=False)
@@ -299,6 +300,15 @@ def template_constant_dict(config, ignore=None, skip_lower=None, toolchain=None)
             # don't fail just because we couldn't resolve this template
             _log.warning("Failed to create mpi_cmd_prefix template, error was:\n%s", err)
 
+    # step 6. CUDA compute capabilities
+    #         Use the commandline / easybuild config option if given, else use the value from the EC (as a default)
+    cuda_compute_capabilities = build_option('cuda_compute_capabilities') or config.get('cuda_compute_capabilities')
+    if cuda_compute_capabilities:
+        template_values['cuda_compute_capabilities'] = ','.join(cuda_compute_capabilities)
+        sm_values = ['sm_' + cc.replace('.', '') for cc in cuda_compute_capabilities]
+        template_values['cuda_sm_comma_sep'] = ','.join(sm_values)
+        template_values['cuda_sm_space_sep'] = ' '.join(sm_values)
+
     return template_values
 
 
