@@ -26,7 +26,8 @@
 # along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
 ##
 """
-EasyBuild support for cgmpolf compiler toolchain (includes Clang, GFortran, MPICH, OpenBLAS, LAPACK, ScaLAPACK and FFTW).
+EasyBuild support for cgmpolf compiler toolchain (includes Clang, GFortran, MPICH, OpenBLAS, LAPACK,
+ScaLAPACK and FFTW).
 
 :author: Dmitri Gribenko (National Technical University of Ukraine "KPI")
 """
@@ -41,4 +42,3 @@ class Cgmpolf(Cgmpich, OpenBLAS, ScaLAPACK, Fftw):
     """Compiler toolchain with Clang, GFortran, MPICH, OpenBLAS, ScaLAPACK and FFTW."""
     NAME = 'cgmpolf'
     SUBTOOLCHAIN = Cgmpich.NAME
-
