@@ -83,6 +83,7 @@ DEFAULT_INDEX_MAX_AGE = 7 * 24 * 60 * 60  # 1 week (in seconds)
 DEFAULT_JOB_BACKEND = 'GC3Pie'
 DEFAULT_LOGFILE_FORMAT = ("easybuild", "easybuild-%(name)s-%(version)s-%(date)s.%(time)s.log")
 DEFAULT_MAX_FAIL_RATIO_PERMS = 0.5
+DEFAULT_MINIMAL_BUILD_ENV = 'CC:gcc,CXX:g++'
 DEFAULT_MNS = 'EasyBuildMNS'
 DEFAULT_MODULE_SYNTAX = 'Lua'
 DEFAULT_MODULES_TOOL = 'Lmod'
@@ -211,6 +212,7 @@ BUILD_OPTIONS_CMDLINE = {
         'skip',
         'stop',
         'subdir_user_modules',
+        'sysroot',
         'test_report_env_filter',
         'testoutput',
         'wait_on_lock',
@@ -236,7 +238,6 @@ BUILD_OPTIONS_CMDLINE = {
         'ignore_index',
         'ignore_locks',
         'install_latest_eb_release',
-        'lib64_fallback_sanity_check',
         'logtostdout',
         'minimal_toolchains',
         'module_extensions',
@@ -251,6 +252,7 @@ BUILD_OPTIONS_CMDLINE = {
         'sequential',
         'set_gid_bit',
         'skip_test_cases',
+        'generate_devel_module',
         'sticky_bit',
         'trace',
         'upload_test_report',
@@ -267,6 +269,8 @@ BUILD_OPTIONS_CMDLINE = {
         'cleanup_tmpdir',
         'extended_dry_run_ignore_errors',
         'fixed_installdir_naming_scheme',
+        'lib64_fallback_sanity_check',
+        'lib64_lib_symlink',
         'mpi_tests',
         'map_toolchains',
         'modules_tool_version_check',
@@ -290,6 +294,9 @@ BUILD_OPTIONS_CMDLINE = {
     DEFAULT_MAX_FAIL_RATIO_PERMS: [
         'max_fail_ratio_adjust_permissions',
     ],
+    DEFAULT_MINIMAL_BUILD_ENV: [
+        'minimal_build_env',
+    ],
     DEFAULT_PKG_RELEASE: [
         'package_release',
     ],
