@@ -54,7 +54,7 @@ def flatten(lst):
     return res
 
 
-def quote_str(val, escape_newline=False, prefer_single_quotes=False, tcl=False):
+def quote_str(val, escape_newline=False, prefer_single_quotes=False, escape_backslash=False, tcl=False):
     """
     Obtain a new value to be used in string replacement context.
 
@@ -66,10 +66,14 @@ def quote_str(val, escape_newline=False, prefer_single_quotes=False, tcl=False):
 
     :param escape_newline: wrap strings that include a newline in triple quotes
     :param prefer_single_quotes: if possible use single quotes
+    :param escape_backslash: escape backslash characters in the string
     :param tcl: Boolean for whether we are quoting for Tcl syntax
     """
 
     if isinstance(val, string_type):
+        # escape backslashes
+        if escape_backslash:
+            val = val.replace('\\', '\\\\')
         # forced triple double quotes
         if ("'" in val and '"' in val) or (escape_newline and '\n' in val):
             return '"""%s"""' % val
@@ -92,7 +96,7 @@ def quote_str(val, escape_newline=False, prefer_single_quotes=False, tcl=False):
 
 def quote_py_str(val):
     """Version of quote_str specific for generating use in Python context (e.g., easyconfig parameters)."""
-    return quote_str(val, escape_newline=True, prefer_single_quotes=True)
+    return quote_str(val, escape_newline=True, prefer_single_quotes=True, escape_backslash=True)
 
 
 def shell_quote(token):
