@@ -79,8 +79,8 @@ class EasyBuildLibTest(TestCase):
     def test_run_cmd(self):
         """Test use of run_cmd function in the context of using EasyBuild framework as a library."""
 
-        error_pattern = "Undefined build option: .*"
-        error_pattern += " Make sure you have set up the EasyBuild configuration using set_up_configuration\(\)"
+        error_pattern = r"Undefined build option: .*"
+        error_pattern += r" Make sure you have set up the EasyBuild configuration using set_up_configuration\(\)"
         self.assertErrorRegex(EasyBuildError, error_pattern, run_cmd, "echo hello")
 
         self.configure()
@@ -95,8 +95,8 @@ class EasyBuildLibTest(TestCase):
 
         test_dir = os.path.join(self.tmpdir, 'test123')
 
-        error_pattern = "Undefined build option: .*"
-        error_pattern += " Make sure you have set up the EasyBuild configuration using set_up_configuration\(\)"
+        error_pattern = r"Undefined build option: .*"
+        error_pattern += r" Make sure you have set up the EasyBuild configuration using set_up_configuration\(\)"
         self.assertErrorRegex(EasyBuildError, error_pattern, mkdir, test_dir)
 
         self.configure()
@@ -109,8 +109,8 @@ class EasyBuildLibTest(TestCase):
     def test_modules_tool(self):
         """Test use of modules_tool function in the context of using EasyBuild framework as a library."""
 
-        error_pattern = "Undefined build option: .*"
-        error_pattern += " Make sure you have set up the EasyBuild configuration using set_up_configuration\(\)"
+        error_pattern = r"Undefined build option: .*"
+        error_pattern += r" Make sure you have set up the EasyBuild configuration using set_up_configuration\(\)"
         self.assertErrorRegex(EasyBuildError, error_pattern, modules_tool)
 
         self.configure()
